@@ -4,14 +4,14 @@
 #include <memory>
 #include <ostream>
 
-#include <bobcat/multistreambuf>
+#include <bobcat/multibuf>
 
 class Options;
 
 namespace FBB
 {
-    class LogBuffer;
-    class Syslogbuf;
+    class LogBuf;
+    class SyslogBuf;
 }
 
 class LogUnit
@@ -21,8 +21,8 @@ class LogUnit
     std::unique_ptr<std::ostream> d_log;
     std::unique_ptr<std::ostream> d_syslog;
 
-    std::unique_ptr<FBB::MultiStreambuf> d_imsgbuf;
-    std::unique_ptr<FBB::MultiStreambuf> d_fmsgbuf;
+    std::unique_ptr<FBB::MultiBuf> d_imsgbuf;
+    std::unique_ptr<FBB::MultiBuf> d_fmsgbuf;
 
     public:
         LogUnit(Options &options);
