@@ -17,7 +17,7 @@ void LogUnit::setupLogs()
 
     unique_ptr<ostream> syslog(newSyslogStream());
 
-    unique_ptr<MultiStreambuf> imsgbuf(new MultiStreambuf);
+    unique_ptr<MultiBuf> imsgbuf(new MultiBuf);
     
     if (log.get() != 0)
     {
@@ -40,7 +40,7 @@ void LogUnit::setupLogs()
         imsg.reset(d_imsgbuf.get());
     }
 
-    unique_ptr<MultiStreambuf> fmsgbuf(new MultiStreambuf);
+    unique_ptr<MultiBuf> fmsgbuf(new MultiBuf);
     fmsgbuf->insert(imsg);
     d_fmsgbuf.swap(fmsgbuf);
 
