@@ -11,11 +11,11 @@ ArgConfig::LongOption longOption[] =
     // Kept for backward compatibility, but a warning is genereated when
     // used
     {"echo-commands", 'e'},             // discont., use --log
-    {"keep-alive", Arg::None},          // discont.: use --daemon
-    {"only-stdout", Arg::None},         // discont.: use --stdout
+    {"keep-alive", Arg::NoArg},          // discont.: use --daemon
+    {"only-stdout", Arg::NoArg},         // discont.: use --stdout
     {"parse-config-file", 'c'},         // discont.: use --parse-policy-file
     {"quiet", 'q'},                     // discont.: use --verbosity 0
-    {"suppress", Arg::None},            // discont.: use --suspend
+    {"suppress", Arg::NoArg},            // discont.: use --suspend
 
 
     {"max-size", Arg::Required},         // 10m by default
@@ -23,8 +23,8 @@ ArgConfig::LongOption longOption[] =
 
     {"log",  'L'},              // : new
 
-    {"log-mail", Arg::None},    // new
-    {"no-mail", Arg::None},     // new
+    {"log-mail", Arg::NoArg},    // new
+    {"no-mail", Arg::NoArg},     // new
 
     {"parse-policy-file", 'p'}, // was: 'c'
 
@@ -34,7 +34,7 @@ ArgConfig::LongOption longOption[] =
     {"skip-files", 's'},        // :
     {"stdout", 'o'},            // new
 
-    {"syslog", Arg::None},              // new (block)
+    {"syslog", Arg::NoArg},              // new (block)
     {"syslog-facility", Arg::Required},
     {"syslog-priority", Arg::Required},
     {"syslog-tag", Arg::Required},
@@ -49,14 +49,14 @@ ArgConfig::LongOption longOption[] =
 
     {"daemon", 'd'},
 
-    {"dry-run", Arg::None},             // new
+    {"dry-run", Arg::NoArg},             // new
 
-    {"ping", Arg::None},                // arg[0] is the uds filename
-    {"rerun", Arg::None},               // also for this and the next options
-    {"resume", Arg::None},
-    {"suspend", Arg::None},
-    {"reload", Arg::None},
-    {"terminate", Arg::None},
+    {"ping", Arg::NoArg},                // arg[0] is the uds filename
+    {"rerun", Arg::NoArg},               // also for this and the next options
+    {"resume", Arg::NoArg},
+    {"suspend", Arg::NoArg},
+    {"reload", Arg::NoArg},
+    {"terminate", Arg::NoArg},
 };
 
 auto endLongOption = longOption + sizeof(longOption) / sizeof(longOption[0]);
