@@ -4,5 +4,5 @@ void Options::foregroundOnly(char const *optionName) const
 {
     if (not d_foreground)
         fmsg << "--" << optionName << " is only valid for a " << 
-                        basename() << " foreground process" << endl;
+                        basename() << " foreground process" << noidl;
 }
