@@ -1,15 +1,17 @@
 #include "policyfile.ih"
 
 void PolicyFile::directivesAndCommands()
+try
 {
-    for (int idx = 0, size = d_configfile.size(); idx != size; ++idx)
-    {
-        string line = d_configfile[idx];
+    ConfigFile configfile(d_options.policyFilePath());
 
-        if (line == "%%")                   // stop at section 2
+    for (size_t idx = 0, size = configfile.size(); idx != size; ++idx)
+    {
+        string line = configfile[idx];
+
+        if (line == "%%")
         {
-            mp << "Policy file processing ends at section 2, line " <<
-                (idx + 1) << endl;
+            loadOptions(configfile, idx + 1);
             return;
         }
 
@@ -31,4 +33,7 @@ void PolicyFile::directivesAndCommands()
         }
     }
 }
-
+catch (exception const &exc)
+{
+    fmsg << exc.what() << noidl;
+}
